diff mbox series

usb: dwc3: gadget: Disable CSP for stream OUT ep

Message ID 3bb329e5-b161-447f-a72f-66e4a95ca5f9@US01WEHTC1.internal.synopsys.com (mailing list archive)
State Superseded
Headers show
Series usb: dwc3: gadget: Disable CSP for stream OUT ep | expand

Commit Message

Tejas Joglekar Dec. 10, 2018, 7:21 a.m. UTC
In stream mode, when fast-forwarding TRBs, the stream number
is not cleared causing the new stream to not get assigned. So
we don't want controller to carry on transfers when short packet
is received. So disable the CSP for stream capable endpoint.

This is based on the 3.30a Programming guide, where table 3-1
device descriptor structure field definitions says for CSP bit
If this bit is 0, the controller generates an XferComplete event
and remove the stream. So if we keep CSP as 1 then switching between
streams would not happen as in stream mode, when fast-forwarding
TRBs, the stream number is not cleared causing the new stream to not get
assigned.

Signed-off-by: Tejas Joglekar <joglekar@synopsys.com>
---
 drivers/usb/dwc3/gadget.c | 10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)

Comments

Felipe Balbi Dec. 10, 2018, 8:34 a.m. UTC | #1
Tejas Joglekar <tejas.joglekar@synopsys.com> writes:

> In stream mode, when fast-forwarding TRBs, the stream number
> is not cleared causing the new stream to not get assigned. So
> we don't want controller to carry on transfers when short packet
> is received. So disable the CSP for stream capable endpoint.
>
> This is based on the 3.30a Programming guide, where table 3-1
> device descriptor structure field definitions says for CSP bit
> If this bit is 0, the controller generates an XferComplete event
> and remove the stream. So if we keep CSP as 1 then switching between
> streams would not happen as in stream mode, when fast-forwarding
> TRBs, the stream number is not cleared causing the new stream to not get
> assigned.
>
> Signed-off-by: Tejas Joglekar <joglekar@synopsys.com>
> ---
>  drivers/usb/dwc3/gadget.c | 10 ++++++++--
>  1 file changed, 8 insertions(+), 2 deletions(-)
>
> diff --git a/drivers/usb/dwc3/gadget.c b/drivers/usb/dwc3/gadget.c
> index f1089ec..0d2afc1 100644
> --- a/drivers/usb/dwc3/gadget.c
> +++ b/drivers/usb/dwc3/gadget.c
> @@ -986,9 +986,15 @@ static void __dwc3_prepare_one_trb(struct dwc3_ep *dep, struct dwc3_trb *trb,
>  				usb_endpoint_type(dep->endpoint.desc));
>  	}
>  
> -	/* always enable Continue on Short Packet */
> +	/*
> +	 * Enable Continue on Short Packet
> +	 * when endpoint is not a stream capable
> +	 */
>  	if (usb_endpoint_dir_out(dep->endpoint.desc)) {
> -		trb->ctrl |= DWC3_TRB_CTRL_CSP;
> +		if (dep->stream_capable)
> +			trb->ctrl &= ~DWC3_TRB_CTRL_CSP;

Is this necessary? Or would it be enough to have this as:

		if (!dep->stream_capable)
			trb->ctrl |= DWC3_TRB_CTRL_CSP;
Tejas Joglekar Dec. 10, 2018, 10:25 a.m. UTC | #2
Hi,
On 12/10/2018 2:04 PM, Felipe Balbi wrote:
> Tejas Joglekar <tejas.joglekar@synopsys.com> writes:
>
>> In stream mode, when fast-forwarding TRBs, the stream number
>> is not cleared causing the new stream to not get assigned. So
>> we don't want controller to carry on transfers when short packet
>> is received. So disable the CSP for stream capable endpoint.
>>
>> This is based on the 3.30a Programming guide, where table 3-1
>> device descriptor structure field definitions says for CSP bit
>> If this bit is 0, the controller generates an XferComplete event
>> and remove the stream. So if we keep CSP as 1 then switching between
>> streams would not happen as in stream mode, when fast-forwarding
>> TRBs, the stream number is not cleared causing the new stream to not get
>> assigned.
>>
>> Signed-off-by: Tejas Joglekar <joglekar@synopsys.com>
>> ---
>>  drivers/usb/dwc3/gadget.c | 10 ++++++++--
>>  1 file changed, 8 insertions(+), 2 deletions(-)
>>
>> diff --git a/drivers/usb/dwc3/gadget.c b/drivers/usb/dwc3/gadget.c
>> index f1089ec..0d2afc1 100644
>> --- a/drivers/usb/dwc3/gadget.c
>> +++ b/drivers/usb/dwc3/gadget.c
>> @@ -986,9 +986,15 @@ static void __dwc3_prepare_one_trb(struct dwc3_ep *dep, struct dwc3_trb *trb,
>>  				usb_endpoint_type(dep->endpoint.desc));
>>  	}
>>  
>> -	/* always enable Continue on Short Packet */
>> +	/*
>> +	 * Enable Continue on Short Packet
>> +	 * when endpoint is not a stream capable
>> +	 */
>>  	if (usb_endpoint_dir_out(dep->endpoint.desc)) {
>> -		trb->ctrl |= DWC3_TRB_CTRL_CSP;
>> +		if (dep->stream_capable)
>> +			trb->ctrl &= ~DWC3_TRB_CTRL_CSP;
> Is this necessary? Or would it be enough to have this as:
Yeah this is enough... I will send the v2
>
> 		if (!dep->stream_capable)
> 			trb->ctrl |= DWC3_TRB_CTRL_CSP;
>
Regards,

Tejas Joglekar
diff mbox series

Patch

diff --git a/drivers/usb/dwc3/gadget.c b/drivers/usb/dwc3/gadget.c
index f1089ec..0d2afc1 100644
--- a/drivers/usb/dwc3/gadget.c
+++ b/drivers/usb/dwc3/gadget.c
@@ -986,9 +986,15 @@  static void __dwc3_prepare_one_trb(struct dwc3_ep *dep, struct dwc3_trb *trb,
 				usb_endpoint_type(dep->endpoint.desc));
 	}
 
 	/* always enable Continue on Short Packet */
 	if (usb_endpoint_dir_out(dep->endpoint.desc)) {
-		trb->ctrl |= DWC3_TRB_CTRL_CSP;
+		if (dep->stream_capable)
+			trb->ctrl &= ~DWC3_TRB_CTRL_CSP;
+		else
+			trb->ctrl |= DWC3_TRB_CTRL_CSP;
 
 		if (short_not_ok)
 			trb->ctrl |= DWC3_TRB_CTRL_ISP_IMI;
@@ -986,9 +986,15 @@  static void __dwc3_prepare_one_trb(struct dwc3_ep *dep, struct dwc3_trb *trb,
 	}
 
-	/* always enable Continue on Short Packet */
+	/*
+	 * Enable Continue on Short Packet
+	 * when endpoint is not a stream capable
+	 */
 	if (usb_endpoint_dir_out(dep->endpoint.desc)) {